teedoc official website
=====

visit: [teedoc.neucrack.com](https://teedoc.neucrack.com/) or [teedoc.github.io](https://teedoc.github.io)


## build locally

* Install teedoc

```
pip3 install teedoc
```

* Get site source files

```
git clone https://github.com/teedoc/teedoc.github.io my_site
```

或者

```
git clone https://github.com/teedoc/teedoc.gitee.io my_site
```

* Install plugins

```
cd my_site
teedoc install
```

* build and serve

```
teedoc build
teedoc serve
```

then visit [http://127.0.0.1:2333](http://127.0.0.1:2333)


